groupedAuthConnectionId property
The grouped auth connection id. If provided, authConnectionId will become a sub identifier for the groupedAuthConnectionId.
Implementation
final String? groupedAuthConnectionId;
The grouped auth connection id. If provided, authConnectionId will become a sub identifier for the groupedAuthConnectionId.
final String? groupedAuthConnectionId;