Chains class

Constructors

Chains({ChainNamespace chainNamespace = ChainNamespace.eip155, int? decimals = 18, String? blockExplorerUrl, required String chainId, String? displayName, required String rpcTarget, String? ticker, String? tickerName})

Properties

blockExplorerUrl → String?
final
chainId → String
final
chainNamespace → ChainNamespace
final
decimals → int?
final
displayName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
final
rpcTarget → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ticker → String?
final
tickerName → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited