LoginParams class

Constructors

LoginParams({required AuthConnection authConnection, String? authConnectionId, String? groupedAuthConnectionId, String? appState, MFALevel? mfaLevel, ExtraLoginOptions? extraLoginOptions, String? dappShare, Curve? curve = Curve.secp256k1, String? dappUrl, String? loginHint, String? idToken})

Properties

appState → String?
final
authConnection → AuthConnection
authConnection sets the oAuth login method to be used. You can use any of the valid AuthConnection from the supported list.
final
authConnectionId → String?
The auth connection id to be used for login.
final
curve → Curve?
curve will be used to determine the public key encoded in the jwt token which returned in getUserInfo function after user login.
final
dappShare → String?
Custom verifier logins can get a dapp share returned to them post successful login. This is useful if the dapps want to use this share to allow users to login seamlessly.
final
dappUrl → String?
final
extraLoginOptions → ExtraLoginOptions?
extraLoginOptions can be used to set the OAuth login options for corresponding AuthConnection.
final
groupedAuthConnectionId → String?
The grouped auth connection id to be used for login.
final
hashCode → int
The hash code for this object.
no setterinherited
idToken → String?
final
loginHint ↔ String?
getter/setter pair
mfaLevel → MFALevel?
Customize the MFA screen shown to the user during OAuth authentication.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited