MfaSetting class

Constructors

MfaSetting({required bool enable, int? priority, bool? mandatory})

Properties

enable → bool
Whether the factor is enabled or not.
final
hashCode → int
The hash code for this object.
no setterinherited
mandatory → bool?
Whether the factor is mandaotry or not for prove the owenership.
final
priority → int?
Priority of the factor over other factors.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited