MfaSettings class

Constructors

MfaSettings({MfaSetting? deviceShareFactor, MfaSetting? backUpShareFactor, MfaSetting? socialBackupFactor, MfaSetting? passwordFactor, MfaSetting? passkeysFactor, MfaSetting? authenticatorFactor})

Properties

authenticatorFactor → MfaSetting?
final
backUpShareFactor → MfaSetting?
Define the settings for backup share factor.
final
deviceShareFactor → MfaSetting?
Define the settings for device share factor.
final
hashCode → int
The hash code for this object.
no setterinherited
passkeysFactor → MfaSetting?
final
passwordFactor → MfaSetting?
Define the settings for password factor.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socialBackupFactor → MfaSetting?
Define the settings for social backup factor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited