redirectUrl property

String redirectUrl
final

Deeplinking for the application where user will be redirected after login. Ideally, it should be bundleId and package name for iOS and Android respectively.

While using redirectUrl, please make sure you have whitelisted it developer dashboard. Checkout SDK reference more details.

Implementation

final String redirectUrl;