WhiteLabelData class

Constructors

WhiteLabelData({String? appName, String? logoLight, String? logoDark, Language? defaultLanguage = Language.en, ThemeModes? mode = ThemeModes.auto, HashMap? theme, String? appUrl, bool? useLogoLoader = false})

Properties

appName → String?
Display name for the app in the UI.
final
appUrl → String?
Url to be used in the Modal
final
defaultLanguage → Language?
Language which will be used by Web3Auth, app will use browser language if not specified.
final
hashCode → int
The hash code for this object.
no setterinherited
logoDark → String?
App logo to be used in light mode.
final
logoLight → String?
App logo to be used in dark mode.
final
mode → ThemeModes?
Theme mode for the login modal
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → HashMap?
Used to customize the theme of the login modal.
final
useLogoLoader → bool?
Use logo loader.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited