UserInfo class

Constructors

UserInfo({String? email, String? name, String? profileImage, String? authConnectionId, String? userId, String? authConnection, String? groupedAuthConnectionId, String? dappShare, String? idToken, String? oAuthIdToken, String? oAuthAccessToken, bool? isMfaEnabled})
const
UserInfo.fromJson(Map<String, dynamic> json)

Properties

authConnection → String?
Type of login choosen by user, like google, facebook, etc.
final
authConnectionId → String?
Details of the verifier type.
final
dappShare → String?
If you are using a Custom Verifier, you can get a dapp share after successful login. This share can act as a replacement to your user's device share.
final
email → String?
Email of the connected user.
final
groupedAuthConnectionId → String?
Details of the aggregate verifier, if present.
final
hashCode → int
The hash code for this object.
no setterinherited
idToken → String?
JWT token issued by the Web3Auth.
final
isMfaEnabled → bool?
Defines whether MFA is enabled or not.
final
name → String?
Name of the connected user.
final
oAuthAccessToken → String?
/ Access token issued by the OAuth provider.
final
oAuthIdToken → String?
JWT token issued by the OAuth provider.
final
profileImage → String?
Profile image of the connected user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String?
Verified id for the custom verifiers.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited