Web3AuthResponse class

Constructors

Web3AuthResponse({String? privateKey, UserInfo? userInfo, String? error, String? ed25519PrivateKey, String? sessionId, String? coreKitKey, String? coreKitEd25519PrivKey, String? factorKey, List<String>? signatures, int? tssShareIndex, String? tssPubKey, String? tssShare, String? tssTag, int? tssNonce, List<int>? nodeIndexes, String? keyMode})
Web3AuthResponse.fromJson(Map<String, dynamic> json)

Properties

coreKitEd25519PrivKey → String?
ed25519 core kit key.
final
coreKitKey → String?
secp256k1 core kit key.
final
ed25519PrivateKey → String?
ed25519 private key compaitible with Solana ecosystem.
final
error → String?
final
factorKey → String?
final
hashCode → int
The hash code for this object.
no setterinherited
keyMode → String?
final
nodeIndexes → List<int>?
final
privateKey → String?
secp256k1 private key compaitible with Ethereum ecosystem.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String?
Current We3Auth sessionId.
final
signatures → List<String>?
final
tssNonce → int?
final
tssPubKey → String?
final
tssShare → String?
final
tssShareIndex → int?
final
tssTag → String?
final
userInfo → UserInfo?
User's information based on the current session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited