AuthConnection enum
Values
- google → const AuthConnection
- facebook → const AuthConnection
- reddit → const AuthConnection
- discord → const AuthConnection
- twitch → const AuthConnection
- github → const AuthConnection
- apple → const AuthConnection
- kakao → const AuthConnection
- linkedin → const AuthConnection
- twitter → const AuthConnection
- weibo → const AuthConnection
- wechat → const AuthConnection
- line → const AuthConnection
- email_passwordless → const AuthConnection
- email_password → const AuthConnection
- custom → const AuthConnection
- sms_passwordless → const AuthConnection
- farcaster → const AuthConnection
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthConnection> - A constant List of the values in this enum, in order of their declaration.