AuthConnectionConfig class

Constructors

AuthConnectionConfig({required AuthConnection authConnection, required String authConnectionId, required String clientId, String? name, String? description, String? groupedAuthConnectionId, String? logoHover, String? logoLight, String? logoDark, bool? mainOption, bool? showOnModal, bool? showOnDesktop, bool? showOnMobile, ExtraLoginOptions? jwtParameters})

Properties

authConnection → AuthConnection
The type of login for custom verifier.
final
authConnectionId → String
Custom verifier name given in the developer dashboard.
final
clientId → String
Client id provided by your login provider used for custom verifier.
final
description → String?
Description for the button. If provided, it renders as a full length button. else, icon button.
final
groupedAuthConnectionId → String?
The grouped auth connection id. If provided, authConnectionId will become a sub identifier for the groupedAuthConnectionId.
final
hashCode → int
The hash code for this object.
no setterinherited
jwtParameters → ExtraLoginOptions?
final
logoDark → String?
Dark logo for the light theme.
final
logoHover → String?
Logo to be shown on mouse hover.
final
logoLight → String?
Light logo for the dark theme.
final
mainOption → bool?
Show login button on the main list.
final
name → String?
Display name for the verifier. If null, the default name is used.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showOnDesktop → bool?
Whether to show the login button on the Desktop.
final
showOnMobile → bool?
Whether to show the login button on Mobile.
final
showOnModal → bool?
Whether to show the login button on Modal.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited