Web3AuthOptions class

Constructors

Web3AuthOptions({required String clientId, required String redirectUrl, Map<String, String>? originData, BuildEnv? authBuildEnv = BuildEnv.production, String? sdkUrl, String? storageServerUrl, String? sessionSocketUrl, List<AuthConnectionConfig>? authConnectionConfig = const [], WhiteLabelData? whiteLabel, String? dashboardUrl, String? accountAbstractionConfig, String? walletSdkUrl, String? sessionNamespace, bool? includeUserDataInToken = true, List<Chains>? chains, String? defaultChainId, bool enableLogging = false, int sessionTime = 30 * 86400, required Web3AuthNetwork web3AuthNetwork, bool? useSFAKey = false, WalletServicesConfig? walletServicesConfig, MfaSettings? mfaSettings, bool isFlutterAnalytics = true, String? sdkVersion})

Properties

accountAbstractionConfig String?
getter/setter pair
authBuildEnv BuildEnv?
authBuildEnv is used for internal testing purposes. This buildEnv signifies the enviroment for Web3Auth, and doesn't signifies the enviorment of the application.
final
authConnectionConfig List<AuthConnectionConfig>?
Login config for the custom verifiers.
getter/setter pair
chains List<Chains>?
getter/setter pair
clientId String
Client id for web3auth.
final
dashboardUrl String?
final
defaultChainId String?
getter/setter pair
enableLogging bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
includeUserDataInToken bool?
includeUserDataInToken allows developers to include user data in the token.
getter/setter pair
isFlutterAnalytics bool
Indicates if this is a Flutter SDK session
getter/setter pair
mfaSettings MfaSettings?
Allows developers to configure the MfaSettings for authentication.
final
originData Map<String, String>?
final
redirectUrl String
Deeplinking for the application where user will be redirected after login. Ideally, it should be bundleId and package name for iOS and Android respectively.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkUrl String?
Define the desired Web3Auth service url.
final
sdkVersion String?
SDK version (used mainly for Flutter SDK)
getter/setter pair
sessionNamespace String?
getter/setter pair
sessionSocketUrl String?
getter/setter pair
sessionTime int
sessionTime allows developers to configure the session management time.
final
storageServerUrl String?
getter/setter pair
useSFAKey bool?
final
walletSdkUrl String?
final
walletServicesConfig WalletServicesConfig?
WhiteLabel options for web3auth. It helps you define custom UI, branding, and translations for your brand app.
final
web3AuthNetwork Web3AuthNetwork
Web3Auth Network to use for the session & the issued idToken.
final
whiteLabel WhiteLabelData?
WhiteLabel options for web3auth. It helps you define custom UI, branding, and translations for your brand app
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited